@@ -1,4 +1,4 @@
-/*	$OpenBSD: bn_ctx.c,v 1.21 2023/04/25 16:41:29 tb Exp $ */
+/*	$OpenBSD: bn_ctx.c,v 1.22 2023/07/08 12:21:58 beck Exp $ */
 /*
  * Copyright (c) 2023 Joel Sing <jsing@openbsd.org>
  *
@@ -70,6 +70,7 @@ BN_CTX_new(void)
 {
 	return calloc(1, sizeof(struct bignum_ctx));
 }
+LCRYPTO_ALIAS(BN_CTX_new);
 
 void
 BN_CTX_free(BN_CTX *bctx)
@@ -89,6 +90,7 @@ BN_CTX_free(BN_CTX *bctx)
 
 	freezero(bctx, sizeof(*bctx));
 }
+LCRYPTO_ALIAS(BN_CTX_free);
 
 void
 BN_CTX_start(BN_CTX *bctx)
@@ -101,6 +103,7 @@ BN_CTX_start(BN_CTX *bctx)
 		return;
 	}
 }
+LCRYPTO_ALIAS(BN_CTX_start);
 
 BIGNUM *
 BN_CTX_get(BN_CTX *bctx)
@@ -139,6 +142,7 @@ BN_CTX_get(BN_CTX *bctx)
 
 	return bn;
 }
+LCRYPTO_ALIAS(BN_CTX_get);
 
 void
 BN_CTX_end(BN_CTX *bctx)
@@ -154,3 +158,4 @@ BN_CTX_end(BN_CTX *bctx)
 
 	bctx->group--;
 }
+LCRYPTO_ALIAS(BN_CTX_end);
