@@ -2,13 +2,13 @@
 
 #include <unistd.h>
 
-#ifdef _MSC_VER
+#ifdef _WIN32
 #include <windows.h>
 #endif
 
 int
 getpagesize(void) {
-#ifdef _MSC_VER
+#ifdef _WIN32
 	SYSTEM_INFO system_info;
 	GetSystemInfo(&system_info);
 	return system_info.dwPageSize;
