@@ -1,4 +1,4 @@
-/* $OpenBSD: encode.c,v 1.28 2020/03/04 11:53:21 inoguchi Exp $ */
+/* $OpenBSD: encode.c,v 1.32 2023/07/07 19:37:53 beck Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -62,6 +62,8 @@
 
 #include <openssl/evp.h>
 
+#include "evp_local.h"
+
 static unsigned char conv_ascii2bin(unsigned char a);
 #define conv_bin2ascii(a)	(data_bin2ascii[(a)&0x3f])
 
