@@ -1,4 +1,4 @@
-/* $OpenBSD: pem_pkey.c,v 1.23 2017/05/02 03:59:44 deraadt Exp $ */
+/* $OpenBSD: pem_pkey.c,v 1.27 2023/07/07 13:40:44 beck Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -73,7 +73,8 @@
 #include <openssl/engine.h>
 #endif
 
-#include "asn1_locl.h"
+#include "asn1_local.h"
+#include "evp_local.h"
 
 int pem_check_suffix(const char *pem_str, const char *suffix);
 
@@ -146,22 +147,34 @@ err:
 	freezero(data, len);
 	return (ret);
 }
+LCRYPTO_ALIAS(PEM_read_bio_PrivateKey);
 
 int
 PEM_write_bio_PrivateKey(BIO *bp, EVP_PKEY *x, const EVP_CIPHER *enc,
     unsigned char *kstr, int klen, pem_password_cb *cb, void *u)
 {
-	char pem_str[80];
-
-	if (!x->ameth || x->ameth->priv_encode)
+	if (x->ameth == NULL || x->ameth->priv_encode != NULL)
 		return PEM_write_bio_PKCS8PrivateKey(bp, x, enc,
 		    (char *)kstr, klen, cb, u);
 
+	return PEM_write_bio_PrivateKey_traditional(bp, x, enc, kstr, klen, cb,
+	    u);
+}
+LCRYPTO_ALIAS(PEM_write_bio_PrivateKey);
+
+int
+PEM_write_bio_PrivateKey_traditional(BIO *bp, EVP_PKEY *x,
+    const EVP_CIPHER *enc, unsigned char *kstr, int klen, pem_password_cb *cb,
+    void *u)
+{
+	char pem_str[80];
+
 	(void) snprintf(pem_str, sizeof(pem_str), "%s PRIVATE KEY",
 	    x->ameth->pem_str);
 	return PEM_ASN1_write_bio((i2d_of_void *)i2d_PrivateKey,
 	    pem_str, bp, x, enc, kstr, klen, cb, u);
 }
+LCRYPTO_ALIAS(PEM_write_bio_PrivateKey_traditional);
 
 EVP_PKEY *
 PEM_read_bio_Parameters(BIO *bp, EVP_PKEY **x)
@@ -202,6 +215,7 @@ err:
 	free(data);
 	return (ret);
 }
+LCRYPTO_ALIAS(PEM_read_bio_Parameters);
 
 int
 PEM_write_bio_Parameters(BIO *bp, EVP_PKEY *x)
@@ -216,6 +230,7 @@ PEM_write_bio_Parameters(BIO *bp, EVP_PKEY *x)
 	return PEM_ASN1_write_bio((i2d_of_void *)x->ameth->param_encode,
 	    pem_str, bp, x, NULL, NULL, 0, 0, NULL);
 }
+LCRYPTO_ALIAS(PEM_write_bio_Parameters);
 
 EVP_PKEY *
 PEM_read_PrivateKey(FILE *fp, EVP_PKEY **x, pem_password_cb *cb, void *u)
@@ -232,6 +247,7 @@ PEM_read_PrivateKey(FILE *fp, EVP_PKEY **x, pem_password_cb *cb, void *u)
 	BIO_free(b);
 	return (ret);
 }
+LCRYPTO_ALIAS(PEM_read_PrivateKey);
 
 int
 PEM_write_PrivateKey(FILE *fp, EVP_PKEY *x, const EVP_CIPHER *enc,
@@ -248,4 +264,4 @@ PEM_write_PrivateKey(FILE *fp, EVP_PKEY *x, const EVP_CIPHER *enc,
 	BIO_free(b);
 	return ret;
 }
-
+LCRYPTO_ALIAS(PEM_write_PrivateKey);
