@@ -1,4 +1,4 @@
-/* $OpenBSD: pkcs7.h,v 1.18 2016/12/27 16:12:47 jsing Exp $ */
+/* $OpenBSD: pkcs7.h,v 1.21 2023/04/25 18:04:03 tb Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -333,7 +333,6 @@ extern const ASN1_ITEM PKCS7_it;
 extern const ASN1_ITEM PKCS7_ATTR_SIGN_it;
 extern const ASN1_ITEM PKCS7_ATTR_VERIFY_it;
 
-int i2d_PKCS7_NDEF(PKCS7 *a, unsigned char **out);
 int PKCS7_print_ctx(BIO *out, PKCS7 *x, int indent, const ASN1_PCTX *pctx);
 
 long PKCS7_ctrl(PKCS7 *p7, int cmd, long larg, char *parg);
@@ -417,10 +416,6 @@ PKCS7 *SMIME_read_PKCS7(BIO *bio, BIO **bcont);
 BIO *BIO_new_PKCS7(BIO *out, PKCS7 *p7);
 
 
-/* BEGIN ERROR CODES */
-/* The following lines are auto generated by the script mkerr.pl. Any changes
- * made after this point may be overwritten when the script is next run.
- */
 void ERR_load_PKCS7_strings(void);
 
 /* Error codes for the PKCS7 functions. */
