@@ -1,4 +1,4 @@
-/* $OpenBSD: asn1time.c,v 1.16 2022/09/05 21:06:31 tb Exp $ */
+/* $OpenBSD: asn1time.c,v 1.17 2023/08/30 10:13:12 job Exp $ */
 /*
  * Copyright (c) 2015 Joel Sing <jsing@openbsd.org>
  *
@@ -528,5 +528,8 @@ main(int argc, char **argv)
 		failed |= asn1_time_test(i, att, V_ASN1_GENERALIZEDTIME);
 	}
 
+	/* Check for a leak in ASN1_TIME_normalize(). */
+	failed |= ASN1_TIME_normalize(NULL) != 0;
+
 	return (failed);
 }
